@@ -48,31 +48,31 @@ const int _gnutls_extensions_size = MAX_EXT_SIZE;
 
 gnutls_extension_entry _gnutls_extensions[MAX_EXT_SIZE] = {
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_MAX_RECORD_SIZE,
-                          EXTENSION_TLS,
+			  EXTENSION_TLS,
 			  _gnutls_max_record_recv_params,
 			  _gnutls_max_record_send_params),
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_CERT_TYPE,
-                          EXTENSION_TLS,
+			  EXTENSION_TLS,
 			  _gnutls_cert_type_recv_params,
 			  _gnutls_cert_type_send_params),
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_SERVER_NAME,
-                          EXTENSION_APPLICATION,
+			  EXTENSION_APPLICATION,
 			  _gnutls_server_name_recv_params,
 			  _gnutls_server_name_send_params),
 #ifdef ENABLE_OPRFI
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_OPAQUE_PRF_INPUT,
-                          EXTENSION_TLS,
+			  EXTENSION_TLS,
 			  _gnutls_oprfi_recv_params,
 			  _gnutls_oprfi_send_params),
 #endif
 #ifdef ENABLE_SRP
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_SRP,
-                          EXTENSION_TLS,
+			  EXTENSION_TLS,
 			  _gnutls_srp_recv_params,
 			  _gnutls_srp_send_params),
 #endif
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_INNER_APPLICATION,
-                          EXTENSION_TLS,
+			  EXTENSION_TLS,
 			  _gnutls_inner_application_recv_params,
 			  _gnutls_inner_application_send_params),
   {NULL, 0, 0, NULL, NULL}
@@ -92,7 +92,10 @@ ext_recv_func
 _gnutls_ext_func_recv (uint16_t type, tls_ext_parse_type_t parse_type)
 {
   ext_recv_func ret = NULL;
-  GNUTLS_EXTENSION_LOOP (if (parse_type == EXTENSION_ANY || p->parse_type == parse_type) ret = p->gnutls_ext_func_recv);
+  GNUTLS_EXTENSION_LOOP (if
+			 (parse_type == EXTENSION_ANY
+			  || p->parse_type == parse_type) ret =
+			 p->gnutls_ext_func_recv);
   return ret;
 
 }
@@ -138,8 +141,9 @@ _gnutls_extension_list_check (gnutls_session_t session, uint16_t type)
 }
 
 int
-_gnutls_parse_extensions (gnutls_session_t session, tls_ext_parse_type_t parse_type, 
-    const opaque * data, int data_size)
+_gnutls_parse_extensions (gnutls_session_t session,
+			  tls_ext_parse_type_t parse_type,
+			  const opaque * data, int data_size)
 {
   int next, ret;
   int pos = 0;
@@ -156,9 +160,8 @@ _gnutls_parse_extensions (gnutls_session_t session, tls_ext_parse_type_t parse_t
       {
 	_gnutls_debug_log ("EXT[%d]: expecting extension '%s'\n",
 			   session,
-			   _gnutls_extension_get_name (session->
-						       internals.
-						       extensions_sent[i]));
+			   _gnutls_extension_get_name
+			   (session->internals.extensions_sent[i]));
       }
 #endif
 
@@ -175,7 +178,7 @@ _gnutls_parse_extensions (gnutls_session_t session, tls_ext_parse_type_t parse_t
       pos += 2;
 
       _gnutls_debug_log ("EXT[%x]: Received extension '%s/%d'\n", session,
-			 _gnutls_extension_get_name (type),type);
+			 _gnutls_extension_get_name (type), type);
 
       if ((ret = _gnutls_extension_list_check (session, type)) < 0)
 	{
@@ -219,8 +222,9 @@ _gnutls_extension_list_add (gnutls_session_t session, uint16_t type)
     {
       if (session->internals.extensions_sent_size < MAX_EXT_TYPES)
 	{
-	  session->internals.extensions_sent[session->internals.
-					     extensions_sent_size] = type;
+	  session->internals.extensions_sent[session->
+					     internals.extensions_sent_size] =
+	    type;
 	  session->internals.extensions_sent_size++;
 	}
       else
