@@ -47,7 +47,7 @@ gnutls_openpgp_crt_init (gnutls_openpgp_crt_t * key)
   *key = gnutls_calloc (1, sizeof (gnutls_openpgp_crt_int));
 
   if (*key)
-    return 0; /* success */
+    return 0;			/* success */
   return GNUTLS_E_MEMORY_ERROR;
 }
 
@@ -95,7 +95,7 @@ gnutls_openpgp_crt_import (gnutls_openpgp_crt_t key,
 
   if (data->data == NULL || data->size == 0)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_OPENPGP_GETKEY_FAILED;
     }
 
@@ -130,7 +130,7 @@ gnutls_openpgp_crt_import (gnutls_openpgp_crt_t key,
   pkt = cdk_kbnode_find_packet (key->knode, CDK_PKT_PUBLIC_KEY);
   if (pkt == NULL)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_OPENPGP_GETKEY_FAILED;
     }
 
@@ -139,11 +139,11 @@ gnutls_openpgp_crt_import (gnutls_openpgp_crt_t key,
 
 /* internal version of export
  */
-int _gnutls_openpgp_export (cdk_kbnode_t node,
-			    gnutls_openpgp_crt_fmt_t format,
-			    void *output_data,
-			    size_t * output_data_size,
-			    int private)
+int
+_gnutls_openpgp_export (cdk_kbnode_t node,
+			gnutls_openpgp_crt_fmt_t format,
+			void *output_data,
+			size_t * output_data_size, int private)
 {
   size_t input_data_size = *output_data_size;
   size_t calc_size;
@@ -161,7 +161,7 @@ int _gnutls_openpgp_export (cdk_kbnode_t node,
    */
   if (!output_data)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_SHORT_MEMORY_BUFFER;
     }
 
@@ -173,7 +173,9 @@ int _gnutls_openpgp_export (cdk_kbnode_t node,
       /* Calculate the size of the encoded data and check if the provided
          buffer is large enough. */
       rc = cdk_armor_encode_buffer (in, *output_data_size,
-				    NULL, 0, &calc_size, private?CDK_ARMOR_SECKEY:CDK_ARMOR_PUBKEY);
+				    NULL, 0, &calc_size,
+				    private ? CDK_ARMOR_SECKEY :
+				    CDK_ARMOR_PUBKEY);
       if (rc || calc_size > input_data_size)
 	{
 	  gnutls_free (in);
@@ -184,7 +186,8 @@ int _gnutls_openpgp_export (cdk_kbnode_t node,
 
       rc = cdk_armor_encode_buffer (in, *output_data_size,
 				    output_data, input_data_size, &calc_size,
-				    private?CDK_ARMOR_SECKEY:CDK_ARMOR_PUBKEY);
+				    private ? CDK_ARMOR_SECKEY :
+				    CDK_ARMOR_PUBKEY);
       gnutls_free (in);
       *output_data_size = calc_size;
     }
@@ -212,7 +215,7 @@ gnutls_openpgp_crt_export (gnutls_openpgp_crt_t key,
 			   gnutls_openpgp_crt_fmt_t format,
 			   void *output_data, size_t * output_data_size)
 {
-  return _gnutls_openpgp_export( key->knode, format, output_data,
+  return _gnutls_openpgp_export (key->knode, format, output_data,
 				 output_data_size, 0);
 }
 
@@ -319,12 +322,12 @@ gnutls_openpgp_crt_get_name (gnutls_openpgp_crt_t key,
   while ((p = cdk_kbnode_walk (key->knode, &ctx, 0)))
     {
       pkt = cdk_kbnode_get_packet (p);
-      if (pkt->pkttype == CDK_PKT_USER_ID) 
-        {
-          if (pos == idx)
-            break;  
-          pos++;
-        }
+      if (pkt->pkttype == CDK_PKT_USER_ID)
+	{
+	  if (pos == idx)
+	    break;
+	  pos++;
+	}
     }
 
   if (!pkt)
@@ -342,7 +345,7 @@ gnutls_openpgp_crt_get_name (gnutls_openpgp_crt_t key,
     }
 
   memcpy (buf, uid->name, uid->len);
-  buf[uid->len] = '\0';	 /* make sure it's a string */
+  buf[uid->len] = '\0';		/* make sure it's a string */
   *sizeof_buf = uid->len + 1;
 
   if (uid->is_revoked)
@@ -375,7 +378,7 @@ gnutls_openpgp_crt_get_pk_algorithm (gnutls_openpgp_crt_t key,
 
   if (!key)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_PK_UNKNOWN;
     }
 
@@ -385,7 +388,7 @@ gnutls_openpgp_crt_get_pk_algorithm (gnutls_openpgp_crt_t key,
     {
       if (bits)
 	*bits = cdk_pk_get_nbits (pkt->pkt.public_key);
-      algo = _gnutls_openpgp_get_algo(pkt->pkt.public_key->pubkey_algo);
+      algo = _gnutls_openpgp_get_algo (pkt->pkt.public_key->pubkey_algo);
     }
 
   return algo;
@@ -502,8 +505,8 @@ gnutls_openpgp_crt_get_key_id (gnutls_openpgp_crt_t key,
     return GNUTLS_E_OPENPGP_GETKEY_FAILED;
 
   cdk_pk_get_keyid (pkt->pkt.public_key, kid);
-  _gnutls_write_uint32( kid[0], keyid);
-  _gnutls_write_uint32( kid[1], keyid+4);
+  _gnutls_write_uint32 (kid[0], keyid);
+  _gnutls_write_uint32 (kid[1], keyid + 4);
 
   return 0;
 }
@@ -534,7 +537,8 @@ gnutls_openpgp_crt_get_revoked_status (gnutls_openpgp_crt_t key)
   if (!pkt)
     return GNUTLS_E_OPENPGP_GETKEY_FAILED;
 
-  if (pkt->pkt.public_key->is_revoked != 0) return 1;
+  if (pkt->pkt.public_key->is_revoked != 0)
+    return 1;
   return 0;
 }
 
@@ -563,34 +567,35 @@ gnutls_openpgp_crt_check_hostname (gnutls_openpgp_crt_t key,
     {
       dnsnamesize = sizeof (dnsname);
       ret = gnutls_openpgp_crt_get_name (key, i, dnsname, &dnsnamesize);
-      
+
       if (ret == 0)
-        {
-          if (_gnutls_hostname_compare (dnsname, hostname))
-            return 1;
-        }
+	{
+	  if (_gnutls_hostname_compare (dnsname, hostname))
+	    return 1;
+	}
     }
 
   /* not found a matching name */
   return 0;
 }
 
-unsigned int _gnutls_get_pgp_key_usage(unsigned int cdk_usage)
+unsigned int
+_gnutls_get_pgp_key_usage (unsigned int cdk_usage)
 {
-unsigned int usage = 0;
+  unsigned int usage = 0;
 
-    if (cdk_usage & CDK_KEY_USG_CERT_SIGN)
-      usage |= GNUTLS_KEY_KEY_CERT_SIGN;
-    if (cdk_usage & CDK_KEY_USG_DATA_SIGN)
-      usage |= GNUTLS_KEY_DIGITAL_SIGNATURE;
-    if (cdk_usage & CDK_KEY_USG_COMM_ENCR)
-      usage |= GNUTLS_KEY_KEY_ENCIPHERMENT;
-    if (cdk_usage & CDK_KEY_USG_STORAGE_ENCR)
-      usage |= GNUTLS_KEY_DATA_ENCIPHERMENT;
-    if (cdk_usage & CDK_KEY_USG_AUTH)
-      usage |= GNUTLS_KEY_KEY_AGREEMENT;
+  if (cdk_usage & CDK_KEY_USG_CERT_SIGN)
+    usage |= GNUTLS_KEY_KEY_CERT_SIGN;
+  if (cdk_usage & CDK_KEY_USG_DATA_SIGN)
+    usage |= GNUTLS_KEY_DIGITAL_SIGNATURE;
+  if (cdk_usage & CDK_KEY_USG_COMM_ENCR)
+    usage |= GNUTLS_KEY_KEY_ENCIPHERMENT;
+  if (cdk_usage & CDK_KEY_USG_STORAGE_ENCR)
+    usage |= GNUTLS_KEY_DATA_ENCIPHERMENT;
+  if (cdk_usage & CDK_KEY_USG_AUTH)
+    usage |= GNUTLS_KEY_KEY_AGREEMENT;
 
-    return usage;
+  return usage;
 }
 
 /**
@@ -620,7 +625,7 @@ gnutls_openpgp_crt_get_key_usage (gnutls_openpgp_crt_t key,
   if (!pkt)
     return GNUTLS_E_OPENPGP_GETKEY_FAILED;
 
-  *key_usage = _gnutls_get_pgp_key_usage(pkt->pkt.public_key->pubkey_usage);
+  *key_usage = _gnutls_get_pgp_key_usage (pkt->pkt.public_key->pubkey_usage);
 
   return 0;
 }
@@ -662,7 +667,8 @@ gnutls_openpgp_crt_get_subkey_count (gnutls_openpgp_crt_t key)
 }
 
 /* returns the subkey with the given index */
-static cdk_packet_t _get_public_subkey(gnutls_openpgp_crt_t key, unsigned int indx)
+static cdk_packet_t
+_get_public_subkey (gnutls_openpgp_crt_t key, unsigned int indx)
 {
   cdk_kbnode_t p, ctx;
   cdk_packet_t pkt;
@@ -673,7 +679,7 @@ static cdk_packet_t _get_public_subkey(gnutls_openpgp_crt_t key, unsigned int in
       gnutls_assert ();
       return NULL;
     }
-  
+
   ctx = NULL;
   subkeys = 0;
   while ((p = cdk_kbnode_walk (key->knode, &ctx, 0)))
@@ -691,8 +697,9 @@ static cdk_packet_t _get_public_subkey(gnutls_openpgp_crt_t key, unsigned int in
  *   pkt->pkt.secret_key;
  *   pkt->pkt.public_key;
  */
-cdk_packet_t _gnutls_openpgp_find_key( cdk_kbnode_t knode, uint32_t keyid[2], 
-  unsigned int priv)
+cdk_packet_t
+_gnutls_openpgp_find_key (cdk_kbnode_t knode, uint32_t keyid[2],
+			  unsigned int priv)
 {
   cdk_kbnode_t p, ctx;
   cdk_packet_t pkt;
@@ -703,23 +710,28 @@ cdk_packet_t _gnutls_openpgp_find_key( cdk_kbnode_t knode, uint32_t keyid[2],
     {
       pkt = cdk_kbnode_get_packet (p);
 
-      if ( (priv == 0 && (pkt->pkttype == CDK_PKT_PUBLIC_SUBKEY || pkt->pkttype == CDK_PKT_PUBLIC_KEY)) || \
-           (priv != 0 && (pkt->pkttype == CDK_PKT_SECRET_SUBKEY || pkt->pkttype == CDK_PKT_SECRET_KEY)))
-        {
-          if (priv == 0)
-            cdk_pk_get_keyid (pkt->pkt.public_key, local_keyid);
-          else
-            cdk_pk_get_keyid (pkt->pkt.secret_key->pk, local_keyid);
+      if ((priv == 0
+	   && (pkt->pkttype == CDK_PKT_PUBLIC_SUBKEY
+	       || pkt->pkttype == CDK_PKT_PUBLIC_KEY)) || (priv != 0
+							   && (pkt->pkttype ==
+							       CDK_PKT_SECRET_SUBKEY
+							       || pkt->
+							       pkttype ==
+							       CDK_PKT_SECRET_KEY)))
+	{
+	  if (priv == 0)
+	    cdk_pk_get_keyid (pkt->pkt.public_key, local_keyid);
+	  else
+	    cdk_pk_get_keyid (pkt->pkt.secret_key->pk, local_keyid);
 
-          if (local_keyid[0] == keyid[0] && \
-            local_keyid[1] == keyid[1]) 
-            {
-              return pkt;
-            }
-        }
+	  if (local_keyid[0] == keyid[0] && local_keyid[1] == keyid[1])
+	    {
+	      return pkt;
+	    }
+	}
     }
 
-  gnutls_assert();
+  gnutls_assert ();
   return NULL;
 }
 
@@ -728,12 +740,13 @@ cdk_packet_t _gnutls_openpgp_find_key( cdk_kbnode_t knode, uint32_t keyid[2],
  *   pkt->pkt.secret_key;
  *   pkt->pkt.public_key;
  */
-int _gnutls_openpgp_find_subkey_idx( cdk_kbnode_t knode, uint32_t keyid[2], 
-  unsigned int priv)
+int
+_gnutls_openpgp_find_subkey_idx (cdk_kbnode_t knode, uint32_t keyid[2],
+				 unsigned int priv)
 {
   cdk_kbnode_t p, ctx;
   cdk_packet_t pkt;
-  int i=0;
+  int i = 0;
   uint32_t local_keyid[2];
 
   ctx = NULL;
@@ -741,24 +754,23 @@ int _gnutls_openpgp_find_subkey_idx( cdk_kbnode_t knode, uint32_t keyid[2],
     {
       pkt = cdk_kbnode_get_packet (p);
 
-      if ( (priv == 0 && (pkt->pkttype == CDK_PKT_PUBLIC_SUBKEY)) || \
-           (priv != 0 && (pkt->pkttype == CDK_PKT_SECRET_SUBKEY)))
-        {
-          if (priv == 0)
-            cdk_pk_get_keyid (pkt->pkt.public_key, local_keyid);
-          else
-            cdk_pk_get_keyid (pkt->pkt.secret_key->pk, local_keyid);
+      if ((priv == 0 && (pkt->pkttype == CDK_PKT_PUBLIC_SUBKEY)) ||
+	  (priv != 0 && (pkt->pkttype == CDK_PKT_SECRET_SUBKEY)))
+	{
+	  if (priv == 0)
+	    cdk_pk_get_keyid (pkt->pkt.public_key, local_keyid);
+	  else
+	    cdk_pk_get_keyid (pkt->pkt.secret_key->pk, local_keyid);
 
-          if (local_keyid[0] == keyid[0] && \
-            local_keyid[1] == keyid[1]) 
-            {
-              return i;
-            }
-          i++;
-        }
+	  if (local_keyid[0] == keyid[0] && local_keyid[1] == keyid[1])
+	    {
+	      return i;
+	    }
+	  i++;
+	}
     }
 
-  gnutls_assert();
+  gnutls_assert ();
   return GNUTLS_E_OPENPGP_SUBKEY_ERROR;
 }
 
@@ -786,11 +798,12 @@ gnutls_openpgp_crt_get_subkey_revoked_status (gnutls_openpgp_crt_t key,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
   if (!pkt)
     return GNUTLS_E_OPENPGP_GETKEY_FAILED;
 
-  if (pkt->pkt.public_key->is_revoked != 0) return 1;
+  if (pkt->pkt.public_key->is_revoked != 0)
+    return 1;
   return 0;
 }
 
@@ -814,25 +827,26 @@ gnutls_openpgp_crt_get_subkey_revoked_status (gnutls_openpgp_crt_t key,
  **/
 gnutls_pk_algorithm_t
 gnutls_openpgp_crt_get_subkey_pk_algorithm (gnutls_openpgp_crt_t key,
-    unsigned int idx, unsigned int *bits)
+					    unsigned int idx,
+					    unsigned int *bits)
 {
   cdk_packet_t pkt;
   int algo;
 
   if (!key)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_PK_UNKNOWN;
     }
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
 
   algo = 0;
   if (pkt)
     {
       if (bits)
 	*bits = cdk_pk_get_nbits (pkt->pkt.public_key);
-      algo = _gnutls_openpgp_get_algo(pkt->pkt.public_key->pubkey_algo);
+      algo = _gnutls_openpgp_get_algo (pkt->pkt.public_key->pubkey_algo);
     }
 
   return algo;
@@ -859,7 +873,7 @@ gnutls_openpgp_crt_get_subkey_creation_time (gnutls_openpgp_crt_t key,
   if (!key)
     return (time_t) - 1;
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
   if (pkt)
     timestamp = pkt->pkt.public_key->timestamp;
   else
@@ -891,7 +905,7 @@ gnutls_openpgp_crt_get_subkey_expiration_time (gnutls_openpgp_crt_t key,
   if (!key)
     return (time_t) - 1;
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
   if (pkt)
     expiredate = pkt->pkt.public_key->expiredate;
   else
@@ -924,13 +938,13 @@ gnutls_openpgp_crt_get_subkey_id (gnutls_openpgp_crt_t key,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
   if (!pkt)
     return GNUTLS_E_OPENPGP_GETKEY_FAILED;
 
   cdk_pk_get_keyid (pkt->pkt.public_key, kid);
-  _gnutls_write_uint32( kid[0], keyid);
-  _gnutls_write_uint32( kid[1], keyid+4);
+  _gnutls_write_uint32 (kid[0], keyid);
+  _gnutls_write_uint32 (kid[1], keyid + 4);
 
   return 0;
 }
@@ -965,7 +979,7 @@ gnutls_openpgp_crt_get_subkey_fingerprint (gnutls_openpgp_crt_t key,
 
   *fprlen = 0;
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
   if (!pkt)
     return GNUTLS_E_OPENPGP_GETKEY_FAILED;
 
@@ -1004,12 +1018,12 @@ gnutls_openpgp_crt_get_subkey_idx (gnutls_openpgp_crt_t key,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  KEYID_IMPORT( kid, keyid);
-  ret = _gnutls_openpgp_find_subkey_idx( key->knode, kid, 0);
+  KEYID_IMPORT (kid, keyid);
+  ret = _gnutls_openpgp_find_subkey_idx (key->knode, kid, 0);
 
   if (ret < 0)
     {
-      gnutls_assert();
+      gnutls_assert ();
     }
 
   return ret;
@@ -1044,80 +1058,94 @@ gnutls_openpgp_crt_get_subkey_usage (gnutls_openpgp_crt_t key,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  pkt = _get_public_subkey( key, idx);
+  pkt = _get_public_subkey (key, idx);
   if (!pkt)
     return GNUTLS_E_OPENPGP_SUBKEY_ERROR;
 
-  *key_usage = _gnutls_get_pgp_key_usage(pkt->pkt.public_key->pubkey_usage);
+  *key_usage = _gnutls_get_pgp_key_usage (pkt->pkt.public_key->pubkey_usage);
 
   return 0;
 }
 
-int _gnutls_read_pgp_mpi( cdk_packet_t pkt, unsigned int priv, size_t idx, bigint_t* m)
+int
+_gnutls_read_pgp_mpi (cdk_packet_t pkt, unsigned int priv, size_t idx,
+		      bigint_t * m)
 {
-size_t buf_size = 512;
-opaque * buf = gnutls_malloc( buf_size);
-int err;
-unsigned int max_pub_params = 0;
+  size_t buf_size = 512;
+  opaque *buf = gnutls_malloc (buf_size);
+  int err;
+  unsigned int max_pub_params = 0;
 
-  if (priv !=0)
-     max_pub_params = cdk_pk_get_npkey(pkt->pkt.secret_key->pk->pubkey_algo);
+  if (priv != 0)
+    max_pub_params = cdk_pk_get_npkey (pkt->pkt.secret_key->pk->pubkey_algo);
 
-  if (buf == NULL) 
+  if (buf == NULL)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_MEMORY_ERROR;
     }
 
   /* FIXME: Note that opencdk doesn't like the buf to be NULL.
    */
   if (priv == 0)
-    err = cdk_pk_get_mpi (pkt->pkt.public_key, idx, buf, buf_size, &buf_size, NULL);
-  else 
+    err =
+      cdk_pk_get_mpi (pkt->pkt.public_key, idx, buf, buf_size, &buf_size,
+		      NULL);
+  else
     {
       if (idx < max_pub_params)
-        err = cdk_pk_get_mpi (pkt->pkt.secret_key->pk, idx, buf, buf_size, &buf_size, NULL);
+	err =
+	  cdk_pk_get_mpi (pkt->pkt.secret_key->pk, idx, buf, buf_size,
+			  &buf_size, NULL);
       else
-        {
-          err = cdk_sk_get_mpi (pkt->pkt.secret_key, idx-max_pub_params, buf, buf_size, &buf_size, NULL);
-        }
+	{
+	  err =
+	    cdk_sk_get_mpi (pkt->pkt.secret_key, idx - max_pub_params, buf,
+			    buf_size, &buf_size, NULL);
+	}
     }
-    
-  if (err == CDK_Too_Short) 
+
+  if (err == CDK_Too_Short)
     {
-      buf = gnutls_realloc_fast( buf, buf_size);
-      if (buf == NULL) 
-        {
-          gnutls_assert();
-          return GNUTLS_E_MEMORY_ERROR;
-        }
+      buf = gnutls_realloc_fast (buf, buf_size);
+      if (buf == NULL)
+	{
+	  gnutls_assert ();
+	  return GNUTLS_E_MEMORY_ERROR;
+	}
 
       if (priv == 0)
-        err = cdk_pk_get_mpi (pkt->pkt.public_key, idx, buf, buf_size, &buf_size, NULL);
+	err =
+	  cdk_pk_get_mpi (pkt->pkt.public_key, idx, buf, buf_size, &buf_size,
+			  NULL);
       else
-        {
-          if (idx < max_pub_params)
-            err = cdk_pk_get_mpi (pkt->pkt.secret_key->pk, idx, buf, buf_size, &buf_size, NULL);
-          else
-            {
-              err = cdk_sk_get_mpi (pkt->pkt.secret_key, idx-max_pub_params, buf, buf_size, &buf_size, NULL);
-            }
-        }
+	{
+	  if (idx < max_pub_params)
+	    err =
+	      cdk_pk_get_mpi (pkt->pkt.secret_key->pk, idx, buf, buf_size,
+			      &buf_size, NULL);
+	  else
+	    {
+	      err =
+		cdk_sk_get_mpi (pkt->pkt.secret_key, idx - max_pub_params,
+				buf, buf_size, &buf_size, NULL);
+	    }
+	}
     }
 
-  if (err != CDK_Success) 
+  if (err != CDK_Success)
     {
-      gnutls_assert();
-      gnutls_free( buf);
-      return _gnutls_map_cdk_rc( err);
+      gnutls_assert ();
+      gnutls_free (buf);
+      return _gnutls_map_cdk_rc (err);
     }
-  
+
   err = _gnutls_mpi_scan (m, buf, buf_size);
-  gnutls_free( buf);
-  
+  gnutls_free (buf);
+
   if (err < 0)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return err;
     }
 
@@ -1128,8 +1156,9 @@ unsigned int max_pub_params = 0;
 /* Extracts DSA and RSA parameters from a certificate.
  */
 int
-_gnutls_openpgp_crt_get_mpis (gnutls_openpgp_crt_t cert, uint32_t *keyid /* [2] */,
-			   bigint_t * params, int *params_size)
+_gnutls_openpgp_crt_get_mpis (gnutls_openpgp_crt_t cert,
+			      uint32_t * keyid /* [2] */ ,
+			      bigint_t * params, int *params_size)
 {
   int result, i;
   int pk_algorithm, local_params;
@@ -1138,54 +1167,54 @@ _gnutls_openpgp_crt_get_mpis (gnutls_openpgp_crt_t cert, uint32_t *keyid /* [2]
   if (keyid == NULL)
     pkt = cdk_kbnode_find_packet (cert->knode, CDK_PKT_PUBLIC_KEY);
   else
-    pkt = _gnutls_openpgp_find_key( cert->knode, keyid, 0);
+    pkt = _gnutls_openpgp_find_key (cert->knode, keyid, 0);
 
   if (pkt == NULL)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_OPENPGP_GETKEY_FAILED;
     }
 
-  pk_algorithm = _gnutls_openpgp_get_algo( pkt->pkt.public_key->pubkey_algo);
+  pk_algorithm = _gnutls_openpgp_get_algo (pkt->pkt.public_key->pubkey_algo);
 
   switch (pk_algorithm)
     {
-      case GNUTLS_PK_RSA:
-        local_params = RSA_PUBLIC_PARAMS;
-        break;
-      case GNUTLS_PK_DSA:
-        local_params = DSA_PUBLIC_PARAMS;
-        break;
-      default:
-        gnutls_assert ();
-        return GNUTLS_E_UNSUPPORTED_CERTIFICATE_TYPE;
+    case GNUTLS_PK_RSA:
+      local_params = RSA_PUBLIC_PARAMS;
+      break;
+    case GNUTLS_PK_DSA:
+      local_params = DSA_PUBLIC_PARAMS;
+      break;
+    default:
+      gnutls_assert ();
+      return GNUTLS_E_UNSUPPORTED_CERTIFICATE_TYPE;
     }
 
-  if (*params_size < local_params) 
+  if (*params_size < local_params)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_INTERNAL_ERROR;
     }
-    
+
   *params_size = local_params;
 
   for (i = 0; i < local_params; i++)
     {
-       result = _gnutls_read_pgp_mpi( pkt, 0, i, &params[i]);
-       if (result < 0)
-         {
-           gnutls_assert();
-           goto error;
-         }
+      result = _gnutls_read_pgp_mpi (pkt, 0, i, &params[i]);
+      if (result < 0)
+	{
+	  gnutls_assert ();
+	  goto error;
+	}
     }
 
   return 0;
-  
+
 error:
   {
     int j;
-    for (j=0;j<i;j++)
-      _gnutls_mpi_release( &params[j]);
+    for (j = 0; j < i; j++)
+      _gnutls_mpi_release (&params[j]);
   }
 
   return result;
@@ -1193,9 +1222,9 @@ error:
 
 /* The internal version of export
  */
-static
-int _get_pk_rsa_raw(gnutls_openpgp_crt_t crt, gnutls_openpgp_keyid_t keyid,
-  gnutls_datum_t * m, gnutls_datum_t * e)
+static int
+_get_pk_rsa_raw (gnutls_openpgp_crt_t crt, gnutls_openpgp_keyid_t keyid,
+		 gnutls_datum_t * m, gnutls_datum_t * e)
 {
   int pk_algorithm, ret, i;
   cdk_packet_t pkt;
@@ -1208,18 +1237,18 @@ int _get_pk_rsa_raw(gnutls_openpgp_crt_t crt, gnutls_openpgp_keyid_t keyid,
       gnutls_assert ();
       return GNUTLS_E_INVALID_REQUEST;
     }
-  
-  KEYID_IMPORT(kid32, keyid);
-  
-  pkt = _gnutls_openpgp_find_key( crt->knode, kid32, 0);
+
+  KEYID_IMPORT (kid32, keyid);
+
+  pkt = _gnutls_openpgp_find_key (crt->knode, kid32, 0);
   if (pkt == NULL)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_OPENPGP_GETKEY_FAILED;
     }
 
-  pk_algorithm = _gnutls_openpgp_get_algo( pkt->pkt.public_key->pubkey_algo);
-  
+  pk_algorithm = _gnutls_openpgp_get_algo (pkt->pkt.public_key->pubkey_algo);
+
   if (pk_algorithm != GNUTLS_PK_RSA)
     {
       gnutls_assert ();
@@ -1258,10 +1287,10 @@ cleanup:
   return ret;
 }
 
-static
-int _get_pk_dsa_raw(gnutls_openpgp_crt_t crt, gnutls_openpgp_keyid_t keyid,
-				gnutls_datum_t * p, gnutls_datum_t * q,
-				gnutls_datum_t * g, gnutls_datum_t * y)
+static int
+_get_pk_dsa_raw (gnutls_openpgp_crt_t crt, gnutls_openpgp_keyid_t keyid,
+		 gnutls_datum_t * p, gnutls_datum_t * q,
+		 gnutls_datum_t * g, gnutls_datum_t * y)
 {
   int pk_algorithm, ret, i;
   cdk_packet_t pkt;
@@ -1274,25 +1303,25 @@ int _get_pk_dsa_raw(gnutls_openpgp_crt_t crt, gnutls_openpgp_keyid_t keyid,
       gnutls_assert ();
       return GNUTLS_E_INVALID_REQUEST;
     }
-  
-  KEYID_IMPORT(kid32, keyid);
-  
-  pkt = _gnutls_openpgp_find_key( crt->knode, kid32, 0);
+
+  KEYID_IMPORT (kid32, keyid);
+
+  pkt = _gnutls_openpgp_find_key (crt->knode, kid32, 0);
   if (pkt == NULL)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_OPENPGP_GETKEY_FAILED;
     }
 
-  pk_algorithm = _gnutls_openpgp_get_algo( pkt->pkt.public_key->pubkey_algo);
-  
+  pk_algorithm = _gnutls_openpgp_get_algo (pkt->pkt.public_key->pubkey_algo);
+
   if (pk_algorithm != GNUTLS_PK_DSA)
     {
       gnutls_assert ();
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  ret = _gnutls_openpgp_crt_get_mpis(crt, kid32, params, &params_size);
+  ret = _gnutls_openpgp_crt_get_mpis (crt, kid32, params, &params_size);
   if (ret < 0)
     {
       gnutls_assert ();
@@ -1365,20 +1394,20 @@ cleanup:
  * Since: 2.4.0
  **/
 int
-gnutls_openpgp_crt_get_pk_rsa_raw (gnutls_openpgp_crt_t crt, 
-				gnutls_datum_t * m, gnutls_datum_t * e)
+gnutls_openpgp_crt_get_pk_rsa_raw (gnutls_openpgp_crt_t crt,
+				   gnutls_datum_t * m, gnutls_datum_t * e)
 {
-gnutls_openpgp_keyid_t keyid;
-int ret;
+  gnutls_openpgp_keyid_t keyid;
+  int ret;
 
-  ret = gnutls_openpgp_crt_get_key_id( crt, keyid);
+  ret = gnutls_openpgp_crt_get_key_id (crt, keyid);
   if (ret < 0)
     {
       gnutls_assert ();
       return ret;
     }
-    
-  return _get_pk_rsa_raw( crt, keyid, m, e);
+
+  return _get_pk_rsa_raw (crt, keyid, m, e);
 }
 
 /**
@@ -1398,21 +1427,21 @@ int ret;
  * Since: 2.4.0
  **/
 int
-gnutls_openpgp_crt_get_pk_dsa_raw (gnutls_openpgp_crt_t crt, 
-				gnutls_datum_t * p, gnutls_datum_t * q,
-				gnutls_datum_t * g, gnutls_datum_t * y)
+gnutls_openpgp_crt_get_pk_dsa_raw (gnutls_openpgp_crt_t crt,
+				   gnutls_datum_t * p, gnutls_datum_t * q,
+				   gnutls_datum_t * g, gnutls_datum_t * y)
 {
-gnutls_openpgp_keyid_t keyid;
-int ret;
+  gnutls_openpgp_keyid_t keyid;
+  int ret;
 
-  ret = gnutls_openpgp_crt_get_key_id( crt, keyid);
+  ret = gnutls_openpgp_crt_get_key_id (crt, keyid);
   if (ret < 0)
     {
       gnutls_assert ();
       return ret;
     }
 
-  return _get_pk_dsa_raw( crt, keyid, p, q, g, y);
+  return _get_pk_dsa_raw (crt, keyid, p, q, g, y);
 }
 
 /**
@@ -1431,20 +1460,22 @@ int ret;
  * Since: 2.4.0
  **/
 int
-gnutls_openpgp_crt_get_subkey_pk_rsa_raw (gnutls_openpgp_crt_t crt, unsigned int idx,
-				gnutls_datum_t * m, gnutls_datum_t * e)
+gnutls_openpgp_crt_get_subkey_pk_rsa_raw (gnutls_openpgp_crt_t crt,
+					  unsigned int idx,
+					  gnutls_datum_t * m,
+					  gnutls_datum_t * e)
 {
-gnutls_openpgp_keyid_t keyid;
-int ret;
+  gnutls_openpgp_keyid_t keyid;
+  int ret;
 
-  ret = gnutls_openpgp_crt_get_subkey_id( crt, idx, keyid);  
+  ret = gnutls_openpgp_crt_get_subkey_id (crt, idx, keyid);
   if (ret < 0)
     {
       gnutls_assert ();
       return ret;
     }
 
-  return _get_pk_rsa_raw( crt, keyid, m, e);
+  return _get_pk_rsa_raw (crt, keyid, m, e);
 }
 
 /**
@@ -1475,14 +1506,14 @@ gnutls_openpgp_crt_get_subkey_pk_dsa_raw (gnutls_openpgp_crt_t crt,
   gnutls_openpgp_keyid_t keyid;
   int ret;
 
-  ret = gnutls_openpgp_crt_get_subkey_id( crt, idx, keyid);
+  ret = gnutls_openpgp_crt_get_subkey_id (crt, idx, keyid);
   if (ret < 0)
     {
       gnutls_assert ();
       return ret;
     }
 
-  return _get_pk_dsa_raw( crt, keyid, p, q, g, y);
+  return _get_pk_dsa_raw (crt, keyid, p, q, g, y);
 }
 
 /**
@@ -1505,7 +1536,7 @@ gnutls_openpgp_crt_get_preferred_key_id (gnutls_openpgp_crt_t key,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  memcpy( keyid, key->preferred_keyid, sizeof(gnutls_openpgp_keyid_t));
+  memcpy (keyid, key->preferred_keyid, sizeof (gnutls_openpgp_keyid_t));
 
   return 0;
 }
@@ -1523,7 +1554,7 @@ int
 gnutls_openpgp_crt_set_preferred_key_id (gnutls_openpgp_crt_t key,
 					 const gnutls_openpgp_keyid_t keyid)
 {
-int ret;
+  int ret;
 
   if (!key)
     {
@@ -1532,16 +1563,16 @@ int ret;
     }
 
   /* check if the id is valid */
-  ret = gnutls_openpgp_crt_get_subkey_idx ( key, keyid);
+  ret = gnutls_openpgp_crt_get_subkey_idx (key, keyid);
   if (ret < 0)
     {
-      _gnutls_x509_log("the requested subkey does not exist\n");
-      gnutls_assert();
+      _gnutls_x509_log ("the requested subkey does not exist\n");
+      gnutls_assert ();
       return ret;
     }
 
   key->preferred_set = 1;
-  memcpy( key->preferred_keyid, keyid, sizeof(gnutls_openpgp_keyid_t));
+  memcpy (key->preferred_keyid, keyid, sizeof (gnutls_openpgp_keyid_t));
 
   return 0;
 }
@@ -1563,62 +1594,65 @@ int ret;
  *
  * Returns: %GNUTLS_E_SUCCESS on success, or an error code.
  **/
-int gnutls_openpgp_crt_get_auth_subkey( gnutls_openpgp_crt_t crt,
-					gnutls_openpgp_keyid_t keyid,
-					unsigned int flag)
+int
+gnutls_openpgp_crt_get_auth_subkey (gnutls_openpgp_crt_t crt,
+				    gnutls_openpgp_keyid_t keyid,
+				    unsigned int flag)
 {
   int ret, subkeys, i;
   unsigned int usage;
   unsigned int keyid_init = 0;
 
-  subkeys = gnutls_openpgp_crt_get_subkey_count( crt);
+  subkeys = gnutls_openpgp_crt_get_subkey_count (crt);
   if (subkeys <= 0)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_OPENPGP_SUBKEY_ERROR;
     }
 
   /* Try to find a subkey with the authentication flag set.
    * if none exists use the last one found
-   */  
-  for (i=0;i<subkeys;i++)
+   */
+  for (i = 0; i < subkeys; i++)
     {
 
-      ret = gnutls_openpgp_crt_get_subkey_revoked_status(crt, i);
-      if (ret != 0) /* it is revoked. ignore it */
+      ret = gnutls_openpgp_crt_get_subkey_revoked_status (crt, i);
+      if (ret != 0)		/* it is revoked. ignore it */
 	continue;
 
       if (keyid_init == 0)
-	{ /* keep the first valid subkey */
-	  ret = gnutls_openpgp_crt_get_subkey_id( crt, i, keyid);
+	{			/* keep the first valid subkey */
+	  ret = gnutls_openpgp_crt_get_subkey_id (crt, i, keyid);
 	  if (ret < 0)
 	    {
-	      gnutls_assert();
+	      gnutls_assert ();
 	      return ret;
 	    }
 
 	  keyid_init = 1;
 	}
 
-      ret = gnutls_openpgp_crt_get_subkey_usage( crt, i, &usage);
+      ret = gnutls_openpgp_crt_get_subkey_usage (crt, i, &usage);
       if (ret < 0)
 	{
-	  gnutls_assert();
+	  gnutls_assert ();
 	  return ret;
 	}
 
       if (usage & GNUTLS_KEY_KEY_AGREEMENT)
-        {
-          ret = gnutls_openpgp_crt_get_subkey_id( crt, i, keyid);
-          if (ret < 0)
-            {
-              gnutls_assert();
-              return ret;
-            }
-          return 0;
-        }
+	{
+	  ret = gnutls_openpgp_crt_get_subkey_id (crt, i, keyid);
+	  if (ret < 0)
+	    {
+	      gnutls_assert ();
+	      return ret;
+	    }
+	  return 0;
+	}
     }
 
-  if (flag && keyid_init) return 0;
-  else return GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
+  if (flag && keyid_init)
+    return 0;
+  else
+    return GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
 }
