@@ -123,11 +123,12 @@ _gnutls_x509_parse_dn (ASN1_TYPE asn1_struct,
       k1++;
       /* create a string like "tbsCertList.issuer.rdnSequence.?1"
        */
-      if (asn1_rdn_name[0]!=0)
-        snprintf( tmpbuffer1, sizeof (tmpbuffer1), "%s.?%u", asn1_rdn_name, k1);
+      if (asn1_rdn_name[0] != 0)
+	snprintf (tmpbuffer1, sizeof (tmpbuffer1), "%s.?%u", asn1_rdn_name,
+		  k1);
       else
-        snprintf( tmpbuffer1, sizeof (tmpbuffer1), "?%u", k1);
-      
+	snprintf (tmpbuffer1, sizeof (tmpbuffer1), "?%u", k1);
+
       len = sizeof (value) - 1;
       result = asn1_read_value (asn1_struct, tmpbuffer1, value, &len);
 
@@ -150,10 +151,11 @@ _gnutls_x509_parse_dn (ASN1_TYPE asn1_struct,
 				 */
 	  k2++;
 
-          if (tmpbuffer1[0] != 0)
-  	    snprintf( tmpbuffer2, sizeof (tmpbuffer2), "%s.?%u", tmpbuffer1, k2);
-          else
-  	    snprintf( tmpbuffer2, sizeof (tmpbuffer2), "?%u", k2);
+	  if (tmpbuffer1[0] != 0)
+	    snprintf (tmpbuffer2, sizeof (tmpbuffer2), "%s.?%u", tmpbuffer1,
+		      k2);
+	  else
+	    snprintf (tmpbuffer2, sizeof (tmpbuffer2), "?%u", k2);
 
 	  /* Try to read the RelativeDistinguishedName attributes.
 	   */
@@ -261,7 +263,7 @@ _gnutls_x509_parse_dn (ASN1_TYPE asn1_struct,
 	  STR_APPEND (ldap_desc);
 	  STR_APPEND ("=");
 	  result = 0;
-	  
+
 	  if (printable)
 	    result =
 	      _gnutls_x509_oid_data2string (oid,
@@ -362,9 +364,10 @@ _gnutls_x509_parse_dn_oid (ASN1_TYPE asn1_struct,
       /* create a string like "tbsCertList.issuer.rdnSequence.?1"
        */
       if (asn1_rdn_name[0] != 0)
-        snprintf( tmpbuffer1, sizeof (tmpbuffer1), "%s.?%u", asn1_rdn_name, k1);
+	snprintf (tmpbuffer1, sizeof (tmpbuffer1), "%s.?%u", asn1_rdn_name,
+		  k1);
       else
-        snprintf( tmpbuffer1, sizeof (tmpbuffer1), "?%u", k1);
+	snprintf (tmpbuffer1, sizeof (tmpbuffer1), "?%u", k1);
 
       len = sizeof (value) - 1;
       result = asn1_read_value (asn1_struct, tmpbuffer1, value, &len);
@@ -389,10 +392,11 @@ _gnutls_x509_parse_dn_oid (ASN1_TYPE asn1_struct,
 				 */
 	  k2++;
 
-          if (tmpbuffer1[0] != 0)
-            snprintf( tmpbuffer2, sizeof (tmpbuffer2), "%s.?%u", tmpbuffer1, k2);
-          else
-            snprintf( tmpbuffer2, sizeof (tmpbuffer2), "?%u", k2);
+	  if (tmpbuffer1[0] != 0)
+	    snprintf (tmpbuffer2, sizeof (tmpbuffer2), "%s.?%u", tmpbuffer1,
+		      k2);
+	  else
+	    snprintf (tmpbuffer2, sizeof (tmpbuffer2), "?%u", k2);
 
 	  /* Try to read the RelativeDistinguishedName attributes.
 	   */
@@ -529,9 +533,10 @@ _gnutls_x509_get_dn_oid (ASN1_TYPE asn1_struct,
       /* create a string like "tbsCertList.issuer.rdnSequence.?1"
        */
       if (asn1_rdn_name[0] != 0)
-        snprintf( tmpbuffer1, sizeof (tmpbuffer1), "%s.?%u", asn1_rdn_name, k1);
+	snprintf (tmpbuffer1, sizeof (tmpbuffer1), "%s.?%u", asn1_rdn_name,
+		  k1);
       else
-        snprintf( tmpbuffer1, sizeof (tmpbuffer1), "?%u", k1);
+	snprintf (tmpbuffer1, sizeof (tmpbuffer1), "?%u", k1);
 
       len = sizeof (value) - 1;
       result = asn1_read_value (asn1_struct, tmpbuffer1, value, &len);
@@ -556,10 +561,11 @@ _gnutls_x509_get_dn_oid (ASN1_TYPE asn1_struct,
 				 */
 	  k2++;
 
-          if (tmpbuffer1[0] != 0)
-            snprintf( tmpbuffer2, sizeof (tmpbuffer2), "%s.?%u", tmpbuffer1, k2);
-          else
-            snprintf( tmpbuffer2, sizeof (tmpbuffer2), "?%u", k2);
+	  if (tmpbuffer1[0] != 0)
+	    snprintf (tmpbuffer2, sizeof (tmpbuffer2), "%s.?%u", tmpbuffer1,
+		      k2);
+	  else
+	    snprintf (tmpbuffer2, sizeof (tmpbuffer2), "?%u", k2);
 
 	  /* Try to read the RelativeDistinguishedName attributes.
 	   */
@@ -943,18 +949,21 @@ _gnutls_x509_set_dn_oid (ASN1_TYPE asn1_struct,
 }
 
 /**
-  * gnutls_x509_dn_init: initialize an opaque DN object
-  *
-  * @odn: the object to be initialized
-  *
-  * This function initializes a #gnutls_x509_dn_t structure.
-  *
-  * The object returned must be deallocated using
-  * gnutls_x509_dn_deinit().
-  *
-  * Returns: 0 on success, or an error code.
-  **/
-int gnutls_x509_dn_init (gnutls_x509_dn_t * odn)
+ * gnutls_x509_dn_init: initialize an opaque DN object
+ * @odn: the object to be initialized
+ *
+ * This function initializes a #gnutls_x509_dn_t structure.
+ *
+ * The object returned must be deallocated using
+ * gnutls_x509_dn_deinit().
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
+ *   negative error value.
+ *
+ * Since: 2.4.0
+ **/
+int
+gnutls_x509_dn_init (gnutls_x509_dn_t * odn)
 {
   int result;
   ASN1_TYPE dn = ASN1_TYPE_EMPTY;
@@ -972,23 +981,24 @@ int gnutls_x509_dn_init (gnutls_x509_dn_t * odn)
   return 0;
 }
 
-
 /**
-  * gnutls_x509_dn_import: get opaque DN object from DER RDN sequence
-  *
-  * @odn: the structure that will hold the imported DN
-  * @data: should contain a DER encoded RDN sequence
-  *
-  * This function parses an RDN sequence and stores the result to a
-  * #gnutls_x509_dn_t structure. The structure must have been initialized
-  * with gnutls_x509_dn_init(). You may use gnutls_x509_dn_get_rdn_ava() to 
-  * decode the DN.
-  *
-  * Returns: 0 on success, or an error code.
-  **/
+ * gnutls_x509_dn_import: get opaque DN object from DER RDN sequence
+ *
+ * @odn: the structure that will hold the imported DN
+ * @data: should contain a DER encoded RDN sequence
+ *
+ * This function parses an RDN sequence and stores the result to a
+ * #gnutls_x509_dn_t structure. The structure must have been initialized
+ * with gnutls_x509_dn_init(). You may use gnutls_x509_dn_get_rdn_ava() to
+ * decode the DN.
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
+ *   negative error value.
+ *
+ * Since: 2.4.0
+ **/
 int
-gnutls_x509_dn_import (gnutls_x509_dn_t odn,
-                       const gnutls_datum_t * data)
+gnutls_x509_dn_import (gnutls_x509_dn_t odn, const gnutls_datum_t * data)
 {
   int result;
   char err[MAX_ERROR_DESCRIPTION_SIZE];
@@ -998,7 +1008,7 @@ gnutls_x509_dn_import (gnutls_x509_dn_t odn,
   if (result != ASN1_SUCCESS)
     {
       /* couldn't decode DER */
-      _gnutls_x509_log("ASN.1 Decoding error: %s\n", err);
+      _gnutls_x509_log ("ASN.1 Decoding error: %s\n", err);
       gnutls_assert ();
       return _gnutls_asn2err (result);
     }
@@ -1007,36 +1017,37 @@ gnutls_x509_dn_import (gnutls_x509_dn_t odn,
 }
 
 /**
-  * gnutls_x509_dn_deinit: deallocate a DN object
-  * @idn: a DN opaque object pointer.
-  *
-  * This function deallocates the DN object as returned by
-  * gnutls_x509_dn_import().
-  *
-  **/
-void 
+ * gnutls_x509_dn_deinit: deallocate a DN object
+ * @idn: a DN opaque object pointer.
+ *
+ * This function deallocates the DN object as returned by
+ * gnutls_x509_dn_import().
+ *
+ * Since: 2.4.0
+ **/
+void
 gnutls_x509_dn_deinit (gnutls_x509_dn_t idn)
 {
   ASN1_TYPE dn = idn;
 
-  asn1_delete_structure(&dn);
+  asn1_delete_structure (&dn);
 }
 
 /**
-  * gnutls_x509_rdn_get - This function parses an RDN sequence and returns a string
-  * @idn: should contain a DER encoded RDN sequence
-  * @buf: a pointer to a structure to hold the peer's name
-  * @sizeof_buf: holds the size of @buf
-  *
-  * This function will return the name of the given RDN sequence.  The
-  * name will be in the form "C=xxxx,O=yyyy,CN=zzzz" as described in
-  * RFC2253.
-  *
-  * If the provided buffer is not long enough, returns
-  * GNUTLS_E_SHORT_MEMORY_BUFFER and *sizeof_buf will be updated.  On
-  * success 0 is returned.
-  *
-  **/
+ * gnutls_x509_rdn_get - parse an RDN sequence and returns a string
+ * @idn: should contain a DER encoded RDN sequence
+ * @buf: a pointer to a structure to hold the peer's name
+ * @sizeof_buf: holds the size of @buf
+ *
+ * This function will return the name of the given RDN sequence.  The
+ * name will be in the form "C=xxxx,O=yyyy,CN=zzzz" as described in
+ * RFC2253.
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS is returned, or
+ * %GNUTLS_E_SHORT_MEMORY_BUFFER is returned and *@sizeof_buf is
+ * updated if the provided buffer is not long enough, otherwise a
+ * negative error value.
+ **/
 int
 gnutls_x509_rdn_get (const gnutls_datum_t * idn,
 		     char *buf, size_t * sizeof_buf)
@@ -1079,23 +1090,24 @@ gnutls_x509_rdn_get (const gnutls_datum_t * idn,
 }
 
 /**
-  * gnutls_x509_rdn_get_by_oid - This function parses an RDN sequence and returns a string
-  * @idn: should contain a DER encoded RDN sequence
-  * @oid: an Object Identifier
-  * @indx: In case multiple same OIDs exist in the RDN indicates which
-  *   to send. Use 0 for the first one.
-  * @raw_flag: If non zero then the raw DER data are returned.
-  * @buf: a pointer to a structure to hold the peer's name
-  * @sizeof_buf: holds the size of @buf
-  *
-  * This function will return the name of the given Object identifier,
-  * of the RDN sequence.  The name will be encoded using the rules
-  * from RFC2253.
-  *
-  * Returns GNUTLS_E_SHORT_MEMORY_BUFFER and updates *sizeof_buf if
-  * the provided buffer is not long enough, and 0 on success.
-  *
-  **/
+ * gnutls_x509_rdn_get_by_oid - parse an RDN sequence and returns a string
+ * @idn: should contain a DER encoded RDN sequence
+ * @oid: an Object Identifier
+ * @indx: In case multiple same OIDs exist in the RDN indicates which
+ *   to send. Use 0 for the first one.
+ * @raw_flag: If non zero then the raw DER data are returned.
+ * @buf: a pointer to a structure to hold the peer's name
+ * @sizeof_buf: holds the size of @buf
+ *
+ * This function will return the name of the given Object identifier,
+ * of the RDN sequence.  The name will be encoded using the rules
+ * from RFC2253.
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS is returned, or
+ * %GNUTLS_E_SHORT_MEMORY_BUFFER is returned and *@sizeof_buf is
+ * updated if the provided buffer is not long enough, otherwise a
+ * negative error value.
+ **/
 int
 gnutls_x509_rdn_get_by_oid (const gnutls_datum_t * idn, const char *oid,
 			    int indx, unsigned int raw_flag,
@@ -1136,19 +1148,22 @@ gnutls_x509_rdn_get_by_oid (const gnutls_datum_t * idn, const char *oid,
 }
 
 /**
-  * gnutls_x509_rdn_get_oid - This function parses an RDN sequence and returns an OID.
-  * @idn: should contain a DER encoded RDN sequence
-  * @indx: Indicates which OID to return. Use 0 for the first one.
-  * @oid: a pointer to a structure to hold the peer's name OID
-  * @sizeof_oid: holds the size of @oid
-  *
-  * This function will return the specified Object identifier, of the
-  * RDN sequence.
-  *
-  * Returns GNUTLS_E_SHORT_MEMORY_BUFFER and updates *sizeof_buf if
-  * the provided buffer is not long enough, and 0 on success.
-  *
-  **/
+ * gnutls_x509_rdn_get_oid - parse an RDN sequence and returns an OID.
+ * @idn: should contain a DER encoded RDN sequence
+ * @indx: Indicates which OID to return. Use 0 for the first one.
+ * @oid: a pointer to a structure to hold the peer's name OID
+ * @sizeof_oid: holds the size of @oid
+ *
+ * This function will return the specified Object identifier, of the
+ * RDN sequence.
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS is returned, or
+ * %GNUTLS_E_SHORT_MEMORY_BUFFER is returned and *@sizeof_buf is
+ * updated if the provided buffer is not long enough, otherwise a
+ * negative error value.
+ *
+ * Since: 2.4.0
+ **/
 int
 gnutls_x509_rdn_get_oid (const gnutls_datum_t * idn,
 			 int indx, void *buf, size_t * sizeof_buf)
@@ -1212,32 +1227,32 @@ _gnutls_x509_compare_raw_dn (const gnutls_datum_t * dn1,
 }
 
 /**
-  * gnutls_x509_dn_export - This function will export the DN
-  * @dn: Holds the opaque DN object
-  * @format: the format of output params. One of PEM or DER.
-  * @output_data: will contain a DN PEM or DER encoded
-  * @output_data_size: holds the size of output_data (and will be
-  *   replaced by the actual size of parameters)
-  *
-  * This function will export the DN to DER or PEM format.
-  *
-  * If the buffer provided is not long enough to hold the output, then
-  * *output_data_size is updated and GNUTLS_E_SHORT_MEMORY_BUFFER will
-  * be returned.
-  *
-  * If the structure is PEM encoded, it will have a header
-  * of "BEGIN NAME".
-  *
-  * Return value: In case of failure a negative value will be
-  * returned, and 0 on success.
-  **/
+ * gnutls_x509_dn_export - This function will export the DN
+ * @dn: Holds the opaque DN object
+ * @format: the format of output params. One of PEM or DER.
+ * @output_data: will contain a DN PEM or DER encoded
+ * @output_data_size: holds the size of output_data (and will be
+ *   replaced by the actual size of parameters)
+ *
+ * This function will export the DN to DER or PEM format.
+ *
+ * If the buffer provided is not long enough to hold the output, then
+ * *@output_data_size is updated and %GNUTLS_E_SHORT_MEMORY_BUFFER
+ * will be returned.
+ *
+ * If the structure is PEM encoded, it will have a header
+ * of "BEGIN NAME".
+ *
+ * Returns: On success, %GNUTLS_E_SUCCESS is returned, otherwise a
+ *   negative error value.
+ **/
 int
 gnutls_x509_dn_export (gnutls_x509_dn_t dn,
-                       gnutls_x509_crt_fmt_t format, void *output_data,
-                       size_t * output_data_size)
+		       gnutls_x509_crt_fmt_t format, void *output_data,
+		       size_t * output_data_size)
 {
   ASN1_TYPE asn1 = dn;
-  
+
   if (asn1 == NULL)
     {
       gnutls_assert ();
@@ -1245,7 +1260,6 @@ gnutls_x509_dn_export (gnutls_x509_dn_t dn,
     }
 
   return _gnutls_x509_export_int_named (asn1, "rdnSequence",
-                                        format, "NAME",
-                                        output_data,
-                                        output_data_size);
+					format, "NAME",
+					output_data, output_data_size);
 }
